@@ -1,4 +1,4 @@
-#source("~/Work/AManal/MCMCglmm_2.12/inst/doc/Figures/buildCN.R")
+#source("~/Work/AManal/MCMCglmm_2.16/inst/doc/Figures/buildCN.R")
 set.seed(32)
 alone=FALSE
 lectures<-1:9
@@ -15,7 +15,7 @@ options(width=80)
 #
 
 UPpath="~/Work/AManal/UP_course/Tex/"
-MCpath="~/Work/AManal/MCMCglmm_2.12/inst/doc/"
+MCpath="~/Work/AManal/MCMCglmm_2.16/inst/doc/"
 
 library(MCMCglmm)
 library(MCMCpack)
@@ -66,7 +66,7 @@ if(length(lectures)>0){
 
    if(alone){
       if(LINUX){
-	system(paste("cp ", MCpath, "JarLib.bib ", UPpath_tmp, sep=""))
+	system(paste("cp ~/Work/Tex/library/JarLib.bib ", UPpath_tmp, sep=""))
         if(lectures[1]==3){
           system(paste("cp ", MCpath, "/rgl1.pdf ", UPpath_tmp, sep=""))
           system(paste("cp ", MCpath, "/rgl2.pdf ", UPpath_tmp, sep=""))
@@ -81,7 +81,7 @@ if(length(lectures)>0){
 
       }else{
 
-	system(paste("cp ", MCpath, "JarLib.bib ", UPpath_tmp, sep=""))
+	system(paste("cp ~/Work/Tex/library/JarLib.bib ", UPpath_tmp, sep=""))
 
 	system(paste("~/Library/TeXShop/bin/pdflatexc", Tex))
 	system(paste("~/Library/TeXShop/bin/bibtexc", Bib))
@@ -101,6 +101,11 @@ if(length(lectures)>0){
   if(alone==FALSE){	
     setwd(MCpath)
     system(paste("cp ", MCpath, "Figures/CourseNotes.Rnw ", MCpath, sep="")) # copy master file back out of figures
+    system(paste("cp ~/Work/Tex/library/JarLib.bib ", MCpath, "CourseNotes.bib", sep="")) 
+    system(paste("cp ~/Work/Tex/library/JarLib.bib ", MCpath, "Overview.bib", sep="")) 
+    system(paste("cp ~/Work/AManal/Tex/jss.cls " , MCpath, sep="")) 
+    system(paste("cp ~/Work/AManal/Tex/jss.bst " , MCpath, sep="")) 
+
     Sweave("CourseNotes.Rnw") 
 
     if(LINUX){
@@ -143,11 +148,13 @@ if(JSS){
 
 
 if(forCRAN){
+	system(paste("bibtool -x ", MCpath, "CourseNotes.aux ", "-o ", MCpath, "CourseNotes.bib", sep=""))
+	system(paste("bibtool -x ", MCpath, "Overview.aux ", "-o ", MCpath, "Overview.bib", sep=""))
 	system(paste("cp ", MCpath, "/CourseNotes.Rnw ", MCpath, "/Figures", sep=""))
 	system(paste("cp ", MCpath, "/CourseNotes.tex ", MCpath, "/CourseNotes.Rnw", sep=""))
-	system(paste("rm ", MCpath, "/CourseNotes.tex", sep=""))
 	system(paste("cp ", MCpath, "/Overview.Rnw ", MCpath, "/Figures", sep=""))
 	system(paste("cp ", MCpath, "/Overview.tex ", MCpath, "/Overview.Rnw", sep=""))	
+	system(paste("rm ", MCpath, "/CourseNotes.tex", sep=""))
 	system(paste("rm ", MCpath, "/Overview.tex", sep=""))
 	system(paste("rm ", MCpath, "*\\.aux", sep=""))
 	system(paste("rm ", MCpath, "*\\.bbl", sep=""))
@@ -156,7 +163,12 @@ if(forCRAN){
 	system(paste("rm ", MCpath, "*\\.toc", sep=""))
 	system(paste("rm ", MCpath, "*\\.out", sep=""))
 	system(paste("rm ", MCpath, "*\\.log", sep=""))
-        system(paste("rm ", MCpath, "Lecture*-[A-Z]*\\.pdf", sep=""))
+	system(paste("rm ", MCpath, "CourseNotes.tex", sep=""))
+	system(paste("rm ", MCpath, "Overview.tex", sep=""))
+	system(paste("rm ", MCpath, "jss.cls", sep=""))
+ 	system(paste("rm ", MCpath, "jss.bst", sep=""))
+        compactPDF(MCpath, gs_cmd="ghostscript")
+ 	system(paste("rm ", MCpath, "Overview.ps", sep=""))
 }
 
 
